//********************************************************************************************************************************
//*                                                                                                                              *
//*     TSpectrum3D V1.1.8.12  3delite 2008-2013                                                                                *
//*     See TSpectrum3D.txt for details                                                                                          *
//*                                                                                                                              *
//* Two licenses are available if you use this library:                                                                          *
//* Shareware License: 50 Euros                                                                                                  *
//* Commercial License: 250 Euros                                                                                                *
//*                                                                                                                              *
//*     http://www.3delite.hu/Object Pascal Developer Resources/tspectrum3d.html                                                 *
//*                                                                                                                              *
//* Note: If you plan using TSpectrum3D in you programs (shareware or commercial), you'll also need a BASS license               *
//* available separatelly from:                                                                                                  *
//*                                                                                                                              *
//*     http://www.un4seen.com/bass.html                                                                                         *
//*                                                                                                                              *
//*     Credits:                                                                                                                 *
//* Ian Luck @ www.un4seen.com - for the great BASS audio library.                                                               *
//*                                                                                                                              *
//* If you have any questions or enquiries please mail: 3delite@3delite.hu                                                       *
//*                                                                                                                              *
//* Good coding! :)                                                                                                              *
//* 3delite                                                                                                                      *
//********************************************************************************************************************************


unit Spectrum3DLibraryDefs;

interface

uses
  Windows, SysUtils, Classes;

    function InitSpectrum3DLibrary: Boolean;
    function FreeSpectrum3DLibrary: Boolean;

const
    Spectrum3DDLL = 'Spectrum3DLibrary.dll';

const
    NAME_Spectrum3DCreate               = 'Spectrum3D_Create';
    NAME_Spectrum3DFree                 = 'Spectrum3D_Free';
    NAME_Spectrum3DSetChannel           = 'Spectrum3D_SetChannel';
    NAME_Spectrum3DGetChannel           = 'Spectrum3D_GetChannel';
    NAME_Spectrum3DRender               = 'Spectrum3D_Render';
    NAME_Spectrum3DReAlign              = 'Spectrum3D_ReAlign';
    NAME_Spectrum3DGetParams            = 'Spectrum3D_GetParams';
    NAME_Spectrum3DSetParams            = 'Spectrum3D_SetParams';

type
    TSpectrum3D_CreateParams = record
        ParentHandle: HWND;
        HardwareVertexProcessing: Bool;
        AntiAliasing: Bool;
    end;

type
    TSpectrum3D_Settings = record
        g_pD3D: Pointer;
        g_pd3dDevice: Pointer;
        GFXZoom: Single;
        GFXScroll: Single;
        GFXAmplitude: Single;
        ShowText: Bool;
        ShowGridLines: Bool;
        GradientGrid: Bool;
    end;

type
    t_Spectrum3D_Create             = function(Params: TSpectrum3D_CreateParams): Pointer; stdcall;
    t_Spectrum3D_Free               = function(Display: Pointer): Bool; stdcall;
    t_Spectrum3D_SetChannel         = function(Display: Pointer; Channel: DWord): Bool; stdcall;
    t_Spectrum3D_GetChannel         = function(Display: Pointer): DWord; stdcall;
    t_Spectrum3D_Render             = function(Display: Pointer): Bool; stdcall;
    t_Spectrum3D_ReAlign            = function(Display: Pointer; ParentHandle: HWND): Bool; stdcall;
    t_Spectrum3D_GetParams          = function(Display: Pointer): TSpectrum3D_Settings; stdcall;
    t_Spectrum3D_SetParams          = function(Display: Pointer; Params: TSpectrum3D_Settings): Bool; stdcall;
var
    Spectrum3D_Create: t_Spectrum3D_Create;
    Spectrum3D_Free: t_Spectrum3D_Free;
    Spectrum3D_SetChannel: t_Spectrum3D_SetChannel;
    Spectrum3D_GetChannel: t_Spectrum3D_GetChannel;
    Spectrum3D_Render: t_Spectrum3D_Render;
    Spectrum3D_ReAlign: t_Spectrum3D_ReAlign;
    Spectrum3D_GetParams: t_Spectrum3D_GetParams;
    Spectrum3D_SetParams: t_Spectrum3D_SetParams;
var
  Spectrum3DDLLHandle: THandle = 0;
  Spectrum3DDLLLoaded: Boolean = False;

implementation

function InitSpectrum3DLibrary: Boolean;
begin
    Spectrum3DDLLHandle := SafeLoadLibrary(PChar(Spectrum3DDLL));
    Result := Spectrum3DDLLHandle <> 0;
    if Result then begin
        Spectrum3D_Create       := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DCreate));
        Spectrum3D_Free         := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DFree));
        Spectrum3D_SetChannel   := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DSetChannel));
        Spectrum3D_GetChannel   := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DGetChannel));
        Spectrum3D_Render       := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DRender));
        Spectrum3D_ReAlign      := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DReAlign));
        Spectrum3D_GetParams    := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DGetParams));
        Spectrum3D_SetParams    := GetProcAddress(Spectrum3DDLLHandle, PChar(NAME_Spectrum3DSetParams));
    end;

    if (@Spectrum3D_Create = nil)
    OR (@Spectrum3D_Free = nil)
    OR (@Spectrum3D_SetChannel = nil)
    OR (@Spectrum3D_GetChannel = nil)
    OR (@Spectrum3D_Render = nil)
    OR (@Spectrum3D_ReAlign = nil)
    OR (@Spectrum3D_GetParams = nil)
    OR (@Spectrum3D_SetParams = nil)
        then Result := False;

    if Result
        then Spectrum3DDLLLoaded := True;
end;

function FreeSpectrum3DLibrary: Boolean;
begin
    Result := False;
    if Spectrum3DDLLHandle <> 0 then begin
        Result := FreeLibrary(Spectrum3DDLLHandle);
        if Result
            then Spectrum3DDLLLoaded := False;
    end;
end;

end.
